summaryrefslogtreecommitdiff
path: root/spec/unit/provider/service/windows_spec.rb
diff options
context:
space:
mode:
authorTim Smith <tsmith@chef.io>2018-07-10 22:51:17 -0700
committerTim Smith <tsmith@chef.io>2018-07-10 22:56:11 -0700
commit26a350996cab459b6483e67a66faf6030bb46312 (patch)
treeaaa00ceb834e017391022e7940152f01fed7ef3c /spec/unit/provider/service/windows_spec.rb
parent293eb409c165b0080178f378211dde1cbb81c916 (diff)
downloadchef-26a350996cab459b6483e67a66faf6030bb46312.tar.gz
Update wording in resource specs for attributes -> properties
Signed-off-by: Tim Smith <tsmith@chef.io>
Diffstat (limited to 'spec/unit/provider/service/windows_spec.rb')
-rw-r--r--spec/unit/provider/service/windows_spec.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/spec/unit/provider/service/windows_spec.rb b/spec/unit/provider/service/windows_spec.rb
index dd59089418..6a82157a64 100644
--- a/spec/unit/provider/service/windows_spec.rb
+++ b/spec/unit/provider/service/windows_spec.rb
@@ -382,7 +382,7 @@ describe Chef::Provider::Service::Windows, "load_current_resource", :windows_onl
provider.action_configure
end
# Attributes that are Strings
%i{binary_path_name load_order_group dependencies run_as_user
display_name description}.each do |attr|
it "configures service if #{attr} has changed" do
@@ -394,7 +394,7 @@ describe Chef::Provider::Service::Windows, "load_current_resource", :windows_onl
end
end
# Attributes that are Integers
%i{service_type error_control}.each do |attr|
it "configures service if #{attr} has changed" do
provider.current_resource.send("#{attr}=", 1)
@@ -570,7 +570,7 @@ describe Chef::Provider::Service::Windows, "load_current_resource", :windows_onl
new_resource.run_as_password("Wensleydale")
end
- it "calls #grant_service_logon if the :run_as_user and :run_as_password attributes are present" do
+ it "calls #grant_service_logon if the :run_as_user and :run_as_password properties are present" do
expect(Win32::Service).to receive(:start)
expect(provider).to receive(:grant_service_logon).and_return(true)
provider.start_service
@@ -382,7 +382,7 @@ describe Chef::Provider::Service::Windows, "load_current_resource", :windows_onl
provider.action_configure
end
- # Attributes that are Strings
+ # properties that are Strings
%i{binary_path_name load_order_group dependencies run_as_user
display_name description}.each do |attr|
@@ -394,7 +394,7 @@ describe Chef::Provider::Service::Windows, "load_current_resource", :windows_onl
end
end
- # Attributes that are Integers
+ # properties that are Integers
%i{service_type error_control}.each do |attr|
it "configures service if #{attr} has changed" do